@@ -17,6 +17,7 @@ char *StrLeft(const char *str, size_t count)
 {
 #ifdef WITH_UTF8
   mbstate_t state;
+  char *p;
 #endif
   char *rez, *tmp;
   size_t len, i;
@@ -31,9 +32,13 @@ char *StrLeft(const char *str, size_t count)
   len = 0;
 
   tmp = Strdup(str);
+#ifdef WITH_UTF8
+  p = tmp;
+#endif
   for (i = 0; i < count; i++) {
 #ifdef WITH_UTF8
     len += mbrlen(p, 4, &state);
+    p = tmp + len;
 #else
     len++;
 #endif
